@@ -508,6 +508,8 @@ void MainWindow::on_fontimport_triggered()
     msgBox.setInformativeText(tr("Note: this function will only import .ttf and .otf fonts from root of MyDocs"));
     msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
     msgBox.setDefaultButton(QMessageBox::Yes);
+    msgBox.button(msgBox.Yes)->setText(tr("Yes"));
+    msgBox.button(msgBox.No)->setText(tr("No"));
     int ret = msgBox.exec();
 
     if ( ret == QMessageBox::Yes ) {
@@ -539,9 +541,10 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Donate some beer money to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-21<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Donate some beer money to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
+    msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
     msgBox.exec();
 }
 
@@ -625,15 +628,38 @@ void MainWindow::savedone()
     presetname.remove(QChar('\"'));
     presetname.remove(QChar(' '));
     presetname.simplified();
+    QFile file("/opt/theme-customizer/presets/" + presetname);
     if (presetname.isEmpty()) {
  //       system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'You must give name for the preset' uint32:0 string:'OK'");
 
         QMaemo5InformationBox::information(this, "You must give name for the preset.",
                                            QMaemo5InformationBox::DefaultTimeout);
 
+    } else if (file.exists()) {
+        QMessageBox msgBox;
+        msgBox.setWindowTitle(tr("Overwrite color preset?"));
+        msgBox.setText(tr("Color preset with this name already exists, do you want to overwrite it?"));
+        msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+        msgBox.setDefaultButton(QMessageBox::Yes);
+        msgBox.button(msgBox.Yes)->setText(tr("Yes"));
+        msgBox.button(msgBox.No)->setText(tr("No"));
+        int ret = msgBox.exec();
+
+        if ( ret == QMessageBox::Yes ) {
+
+            if (file.exists()) file.remove();
+            file.open(QIODevice::WriteOnly | QIODevice::Text);
+            QTextStream out(&file);
+            out << "DefaultTextColor=" << f1 << "\n" << "SecondaryTextColor=" << f2 << "\n" << "ActiveTextColor=" << f3 << "\n" << "DisabledTextColor=" << f4 << "\n" << "PaintedTextColor=" << f5 << "\n" << "SelectionColor=" << f6 << "\n" << "ButtonTextColor=" << f7 << "\n" << "ButtonTextPressedColor=" << f8 << "\n";
+
+            // optional, as QFile destructor will already do it:
+            file.close();
+            SaveWin->hide();
+            QMaemo5InformationBox::information(this, "Preset saved!",
+                                               QMaemo5InformationBox::DefaultTimeout);
+
+        }
     } else {
-        QFile file("/opt/theme-customizer/presets/" + presetname);
-        if (file.exists()) file.remove();
         file.open(QIODevice::WriteOnly | QIODevice::Text);
         QTextStream out(&file);
         out << "DefaultTextColor=" << f1 << "\n" << "SecondaryTextColor=" << f2 << "\n" << "ActiveTextColor=" << f3 << "\n" << "DisabledTextColor=" << f4 << "\n" << "PaintedTextColor=" << f5 << "\n" << "SelectionColor=" << f6 << "\n" << "ButtonTextColor=" << f7 << "\n" << "ButtonTextPressedColor=" << f8 << "\n";
@@ -671,8 +697,21 @@ void MainWindow::loadclicked()
 void MainWindow::delclicked()
 {
     QFile file("/opt/theme-customizer/presets/" + ManWin->ui->presetslist->currentText());
-    if (file.exists()) file.remove();
-    ManWin->hide();
-    QMaemo5InformationBox::information(this, "Preset deleted.",
-                                       QMaemo5InformationBox::DefaultTimeout);
+    QMessageBox msgBox;
+    msgBox.setWindowTitle(tr("Delete color preset?"));
+    msgBox.setText(tr("Are you sure you want to delete this preset?"));
+    msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+    msgBox.setDefaultButton(QMessageBox::Yes);
+    msgBox.button(msgBox.Yes)->setText(tr("Yes"));
+    msgBox.button(msgBox.No)->setText(tr("No"));
+    int ret = msgBox.exec();
+
+    if ( ret == QMessageBox::Yes ) {
+
+        if (file.exists()) file.remove();
+        ManWin->hide();
+        QMaemo5InformationBox::information(this, "Preset deleted.",
+                                           QMaemo5InformationBox::DefaultTimeout);
+
+    }
 }
