@@ -18,6 +18,41 @@
         <source>Reading settings</source>
         <translation>Asetusten lataus</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Ok, thanks.</source>
+        <translation>Sulje</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Overwrite color preset?</source>
+        <translation>Ylikirjoitetaanko väripresetti?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Color preset with this name already exists, do you want to overwrite it?</source>
+        <translation>Tällä nimellä on jo tallennettu väripresetti, ylikirjoitetaanko?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Yes</source>
+        <translation>Kyllä</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>No</source>
+        <translation>Ei</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Delete color preset?</source>
+        <translation>Poistetaanko väripresetti?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Are you sure you want to delete this preset?</source>
+        <translation>Oletko varma että haluat poistaa väripresetin?</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Color presets</source>
