@@ -8,6 +8,61 @@
         <source>Theme Customizer</source>
         <translation>Customiser le thème</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Reading settings...</source>
+        <translation>Chargement des paramètres...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Reading settings</source>
+        <translation>Chargement des paramètres</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Ok, thanks.</source>
+        <translation>Ok, merci.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Overwrite color preset?</source>
+        <translation>Ecraser la présélection?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Color preset with this name already exists, do you want to overwrite it?</source>
+        <translation>La présélection avec ce nom existe, voulez-vous l&apos;écraser?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Yes</source>
+        <translation>Oui</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>No</source>
+        <translation>Non</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Delete color preset?</source>
+        <translation>Effacer la présélection de couleur?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Are you sure you want to delete this preset?</source>
+        <translation>Etes-vous sur de vouloir effacer cette présélection?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Color presets</source>
+        <translation>Présélections de couleur</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Save color preset</source>
+        <translation>Enregistrer les couleurs</translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="81"/>
         <source>Font</source>
@@ -21,7 +76,7 @@
     <message>
         <location filename="mainwindow.ui" line="147"/>
         <source>DEFAULT</source>
-        <translation>Défaut</translation>
+        <translation>Par défaut</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="152"/>
@@ -81,7 +136,7 @@
     <message>
         <location filename="mainwindow.ui" line="360"/>
         <source>Painted font</source>
-        <translation>Coloré</translation>
+        <translation>Colorée</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
@@ -96,7 +151,7 @@
     <message>
         <location filename="mainwindow.ui" line="394"/>
         <source>&quot;Paint&quot; color</source>
-        <translation>&quot;Paint&quot; couleur</translation>
+        <translation>Couleur &quot;Paint&quot;</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="437"/>
@@ -121,7 +176,7 @@
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Widget opacity</source>
-        <translation type="unfinished"></translation>
+        <translation>Opacité</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="560"/>
@@ -131,7 +186,7 @@
     <message>
         <location filename="mainwindow.ui" line="575"/>
         <source>Web bookmark size</source>
-        <translation>Tailles des favoris</translation>
+        <translation>Taille des favoris</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="721"/>
@@ -167,7 +222,7 @@
     <message>
         <location filename="mainwindow.ui" line="788"/>
         <source>About</source>
-        <translation>A propos</translation>
+        <translation>A propos de</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
@@ -183,7 +238,7 @@
         <location filename="mainwindow.cpp" line="7"/>
         <location filename="mainwindow.cpp" line="8"/>
         <source>Abort</source>
-        <translation>Annulé</translation>
+        <translation>Annuler</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="8"/>
@@ -208,7 +263,7 @@
     <message>
         <location filename="mainwindow.cpp" line="362"/>
         <source>Note: this function will only import .ttf and .otf fonts from root of MyDocs</source>
-        <translation>Note: Cette fonction importe seulement les fontes .ttf et .otf depuis Le dossier &quot;MyDocs&quot;</translation>
+        <translation>Note: Cette fonction importe seulement les fontes .ttf et .otf depuis le dossier &quot;MyDocs&quot;</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="370"/>
@@ -218,7 +273,7 @@
     <message>
         <location filename="mainwindow.cpp" line="393"/>
         <source>About Theme Customizer</source>
-        <translation>A propos de Theme Customizer</translation>
+        <translation>A propos de &quot;Theme Customizer&quot;</translation>
     </message>
 </context>
 <context>
@@ -226,37 +281,41 @@
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Clock</source>
-        <translation type="unfinished"></translation>
+        <translation>Horloge
+ &amp; Alarme</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>App Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>Gestionnaire
+ d&apos;application</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Media Player</source>
-        <translation type="unfinished"></translation>
+        <translation>Lecteur
+ multimédia</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Lockscreen</source>
-        <translation type="unfinished"></translation>
+        <translation>Ecran de
+ déverrouillage</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Tap me to change</source>
-        <translation type="unfinished"></translation>
+        <translation>Cliquez pour changer</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Set image</source>
-        <translation type="unfinished"></translation>
+        <translation>Appliquer</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Backgrounds</source>
-        <translation type="unfinished"></translation>
+        <translation>Fond d&apos;écran</translation>
     </message>
 </context>
 <context>
@@ -264,17 +323,17 @@
     <message>
         <location filename="savepreset.ui" line="0"/>
         <source>Save color preset as...</source>
-        <translation type="unfinished"></translation>
+        <translation>Enregistrer la présélection de couleurs sous...</translation>
     </message>
     <message>
         <location filename="savepreset.ui" line="0"/>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation>Enregistrer</translation>
     </message>
     <message>
         <location filename="savepreset.ui" line="0"/>
         <source>Save color preset</source>
-        <translation type="unfinished"></translation>
+        <translation>Enregistrer la présélection de couleurs</translation>
     </message>
 </context>
 <context>
@@ -282,27 +341,27 @@
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Choose color preset:</source>
-        <translation type="unfinished"></translation>
+        <translation>Choisir la présélection de couleurs:</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Currently active colors</source>
-        <translation type="unfinished"></translation>
+        <translation>Couleurs actives</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Load</source>
-        <translation type="unfinished"></translation>
+        <translation>Charger</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Effacer</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Manage color presets</source>
-        <translation type="unfinished"></translation>
+        <translation>Gestion des présélections de couleurs</translation>
     </message>
 </context>
 </TS>
